@@ -2,7 +2,7 @@ package PGXN::Site;
 
 use 5.10.0;
 use utf8;
-our $VERSION = v0.20.2;
+our $VERSION = v0.20.3;
 
 sub version_string {
     sprintf 'v%vd', $VERSION;
@@ -86,7 +86,7 @@ Returns a string representation of the PGXN::Site version.
 
 =head1 Author
 
-David E. Wheeler <david.wheeler@pgexperts.com>
+David E. Wheeler <david@justatheory.com>
 
 =head1 Copyright and License
 
