@@ -6,7 +6,7 @@ use parent 'Locale::Maketext';
 use I18N::LangTags::Detect;
 use File::Spec;
 use Carp;
-our $VERSION = v0.20.2;
+our $VERSION = v0.20.3;
 
 # Allow unknown phrases to just pass-through.
 our %Lexicon = (
@@ -269,7 +269,7 @@ will be F<PGXN/Site/Locale/fr/foo/bar.html>.
 
 =head1 Author
 
-David E. Wheeler <david.wheeler@pgexperts.com>
+David E. Wheeler <david@justatheory.com>
 
 =head1 Copyright and License
 
