@@ -3,7 +3,7 @@ package PGXN::Site::Locale::fr;
 use 5.10.0;
 use utf8;
 use parent 'PGXN::Site::Locale';
-our $VERSION = v0.20.2;
+our $VERSION = v0.20.3;
 
 our %Lexicon = (
     listcomma => ',',
@@ -30,7 +30,7 @@ Subclass of L<PGXN::Site::Locale> providing French localization.
 
 =head1 Author
 
-David E. Wheeler <david.wheeler@pgexperts.com>
+David E. Wheeler <david@justatheory.com>
 
 =head1 Copyright and License
 
